Stay Informed
=============

Check the following sources often to keep up on new features and other changes.

GitHub
------

The `project page <https://github.com/sporestack/bitcash>`_ on GitHub remains the best
way to track the development of bitcash.

Twitter
-------

Feel free to follow `@merc1er <https://twitter.com/merc1er>`_ on
Twitter for occasional updates.

.. include:: ../../../HISTORY.rst
